@@ -234,7 +234,7 @@ around downloads_config => sub {
   my $params = $self->$orig(@_);
 
   for (qw/download_dir watch_dir/) {
-    $params->{result}{$_} = decode_base64( $params->{result}{$_} ) if exists $params->{result}{$_} and $params->{result}{$_};
+    $params->{$_} = decode_base64( $params->{$_} ) if exists $params->{$_} and $params->{$_};
   }
 
   $params;
@@ -313,8 +313,8 @@ around list_files => sub {
   $params = encode_base64( $params, "") if $params;
   my $res = $self->$orig($params);
 
-  for my $i ( 0.. $#{$res->{result}} ) {
-    $res->{result}->[$i]{path} = decode_base64( $res->{result}[$i]{path} );
+  for my $i ( 0.. $#{$res} ) {
+    $res->[$i]{path} = decode_base64( $res->[$i]{path} );
   }
 
   $res;
@@ -340,7 +340,7 @@ around file_info => sub {
   my $res = $self->$orig($params);
 
   for (qw/parent target path/) {
-    $params->{result}{$_} = decode_base64( $params->{result}{$_} ) if exists $params->{result}{$_} and $params->{result}{$_};
+    $params->{$_} = decode_base64( $params->{$_} ) if exists $params->{$_} and $params->{$_};
   }
 
   $params;
@@ -448,7 +448,7 @@ around upload_file => sub {
       my $res = $self->upload_auth(@_);
       delete $params->{dirname};
       delete $params->{upload_name};
-      $id = $res->{result}{id};
+      $id = $res->{id};
     }
     $params->{name} = [ $filename ];
     $params->{suff} = "$id/send";
@@ -512,6 +512,26 @@ Global Connection getters.
   required => [],
 ) for qw(connection connection/config connection/ipv6/config connection/xdsl/ connection/ftth);
 
+fbx_api_method upd_connection => (
+  description => <<'',
+Update the connection configuration.
+
+  path => 'connection/config/',
+  method => 'PUT',
+  params => [qw/ping remote_access remote_access_port wol adblock allow_token_request/],
+  required => [qw//],
+);
+
+fbx_api_method upd_ipv6_config => (
+  description => <<'',
+Update the ipv6 connection configuration.
+
+  path => 'connection/ipv6/config/',
+  method => 'PUT',
+  params => [qw/ ipv6_enabled delegations/],
+  required => [qw//],
+);
+
 fbx_api_method connection_dyndns => (
   description => <<'',
 Get status or config of dyndns provider.
@@ -522,6 +542,16 @@ Get status or config of dyndns provider.
   required => [qw/suff/],
 );
 
+fbx_api_method upd_connection_dyndns => (
+  description => <<'',
+Set config of dyndns provider.
+
+  path => 'connection/ddns/',
+  method => 'GET',
+  params => [qw/suff enabled user password hostname/],
+  required => [qw/suff/],
+);
+
 #LAN
 fbx_api_method s'/'_'gr => (
   description => <<'',
@@ -533,6 +563,16 @@ Global Lan getters.
   required => [],
 ) for qw(lan/config lan/browser/interfaces);
 
+fbx_api_method upd_lan_config => (
+  description => <<'',
+Update lan config.
+
+  path => 'lan/config/',
+  method => 'PUT',
+  params => [ qw/mode ip name name_dns name_mdns name_netbios/ ],
+  required => [ qw// ],
+);
+
 fbx_api_method list_hosts => (
   description => <<'',
 Get the list of hosts on a given interface.
@@ -543,6 +583,26 @@ Get the list of hosts on a given interface.
   required => [ qw/suff/ ],
 );
 
+fbx_api_method upd_host => (
+  description => <<'',
+Update a host config.
+
+  path => 'lan/browser/',
+  method => 'PUT',
+  params => [ qw/suff id primary_name host_type persistent / ],
+  required => [ qw/suff id/ ],
+);
+
+fbx_api_method wol_host => (
+  description => <<'',
+Send a WoL.
+
+  path => 'lan/wol/',
+  method => 'POST',
+  params => [ qw/suff mac password/ ],
+  required => [ qw/suff mac/ ],
+);
+
 #Freeplugs
 fbx_api_method freeplugs_net => (
   description => <<'',
@@ -574,6 +634,7 @@ Global DHCP getters.
   params => [ ],
   required => [ ],
 ) for qw(dhcp/config dhcp/static_lease dhcp/dynamic_lease);
+#TODO finish
 
 #FTP
 
@@ -607,6 +668,7 @@ Global NAT getters.
   params => [ ],
   required => [ ],
 ) for qw(fw/dmz fw/redir/ fw/incoming/);
+#TODO rest
 
 #UPNP
 fbx_api_method s'/'_'gr => (
@@ -618,6 +680,7 @@ Global UPNP getters.
   params => [ ],
   required => [ ],
 ) for qw(upnpigd/config upnpigd/redir/);
+#TODO rest
 
 #LCD
 fbx_api_method lcd => (
@@ -649,6 +712,7 @@ Global Network Shares getters.
   params => [ ],
   required => [ ],
 ) for qw(netshare/samba netshare/afp);
+#TODO rest
 
 #UPNPAV
 fbx_api_method upnpav => (
@@ -681,6 +745,26 @@ Get the switch status.
   required => [ ],
 );
 
+fbx_api_method switch_port => (
+  description => <<'',
+Get the switch port config and status.
+
+  path => 'switch/port/',
+  method => 'GET',
+  params => [ qw/suff/ ],
+  required => [ qw/suff/ ],
+);
+
+fbx_api_method set_switch_port => (
+  description => <<'',
+Update a port config.
+
+  path => 'switch/port/',
+  method => 'PUT',
+  params => [ qw/suff duplex speed/ ],
+  required => [ qw/suff/ ],
+);
+
 #wifi
 fbx_api_method s'/'_'gr => (
   description => <<'',
@@ -692,6 +776,8 @@ Global Wifi getters.
   required => [ ],
 ) for qw(wifi/config wifi/ap wifi/bss wifi/planning wifi/mac_filter);
 
+#TODO finish
+
 #System
 fbx_api_method system => (
   description => <<'',
@@ -734,6 +820,7 @@ Global VPN client getters.
   params => [ ],
   required => [ ],
 ) for qw(vpn_client/config/ vpn_client/status vpn_client/log);
+#TODO finish
 
 #Storage
 fbx_api_method s'/'_'gr => (
@@ -745,6 +832,7 @@ Global storage getters.
   params => [ ],
   required => [ ],
 ) for qw(storage/disk/ storage/partition/);
+#TODO finish
 
 #Parental
 fbx_api_method s'/'_'gr => (
@@ -756,7 +844,7 @@ Global parental getters.
   params => [ ],
   required => [ ],
 ) for qw(parental/config/ parental/filter/);
-
+#TODO finish
 
 1;
 __END__
@@ -794,11 +882,11 @@ $fbx->contact;
 
 =head3 connection
 
-$fbx->connection;
+ $res = $fbx->connection;
 
 =head3 connection config
 
-$fbx->connection_config;
+ $res = $fbx->connection_config;
 
 =head3 connection ipv6 config
 
@@ -812,9 +900,21 @@ $fbx->connection_xdsl;
 
 $fbx->connection_ftth;
 
+=head3 update connection config
+
+ $res = $fbx->upd_connection({ping=>\1});
+
+=head3 update connection ipv6 config
+
+ $res = $fbx->upd_ipv6_config({ipv6_enabled=>\0});
+
 =head3 connection dyndns noip
 
-$fbx->connection_dyndns("noip/status");
+$res = $fbx->connection_dyndns("noip/status");
+
+=head3 connection dyndns noip
+
+$res = $fbx->upd_connection_dyndns("noip/status", {enabled=>\0});
 
 =head2 dhcp
 
@@ -836,45 +936,9 @@ $fbx->dhcp_dynamic_lease;
 
 $fbx->downloads;
 
-=head3 download task
+=head3 downloads config
 
-$fbx->get_download_task( 77 );
-
-=head3 download task log
-
-$fbx->get_download_task( "77/log" );
-
-=head3 downloads task del
-
-$fbx->del_download_task( 77 );
-
-=head3 downloads task del with file erase
-
-$fbx->del_download_task( "77/erase" );
-
-=head3 downloads update
-
-$fbx->upd_download_task( 0, { io_priority => "high" } );
-
-=head3 download add
-
-$res = $fbx->add_download_task( { download_url => "http://cdimage.debian.org/debian-cd/current/arm64/bt-cd/debian-8.4.0-arm64-CD-1.iso.torrent"} );
-
-=head3 download add by local file
-
-$res=$fbx->add_download_task_file( {download_file => [ "debian-8.4.0-arm64-netinst.iso.torrent" ] });
-
-=head3 update priority of download file
-
-$res=$fbx->change_prio_download_file( "76/files/76-0", { priority=>"high"} );
-
-=head3 download tracker
-
-$res = $fbx->get_download_task( "76/trackers");
-
-=head3 download peers
-
-$res = $fbx->get_download_task( "76/peers");
+$fbx->downloads_config;
 
 =head3 downloads stats
 
@@ -884,21 +948,89 @@ $fbx->downloads_stats;
 
 $fbx->downloads_feeds;
 
+=head3 downloads config
+
+ $res = $fbx->downloads_config;
+
+=head3 download tasks
+
+ $res = $fbx->get_download_task;
+
+=head3 download add
+
+ $res = $fbx->add_download_task( { download_url => "http://cdimage.debian.org/debian-cd/current/arm64/bt-cd/debian-8.4.0-arm64-CD-1.iso.torrent"} );
+
+=head3 update downloads config
+
+$res = $fbx->upd_downloads_config({max_downloading_tasks => $max_dl_tasks});
+
+=head3 update throttling
+
+$res = $fbx->upd_downloads_throttle( "schedule" );
+
+=head3 download tasks
+
+ $res = $fbx->get_download_task;
+
+=head3 download task
+
+$res = $fbx->get_download_task( $id );
+
+=head3 download task log
+
+$res = $fbx->get_download_task( "$id/log" );
+
+=head3 downloads update
+
+$fbx->upd_download_task( $id, { io_priority => "high" } );
+
+=head3 get download task files
+
+$res = $fbx->get_download_task("$id/files") ;
+
+=head3 update priority of download file
+
+$res = $fbx->change_prio_download_file( "$id/files/$id_file", { priority=>"high"} );
+
+=head3 downloads task del
+
+$res = $fbx->del_download_task( $id );
+
+=head3 download add by local file
+
+$res = $fbx->add_download_task_file( {download_file => [ "mine/debian-8.4.0-arm64-netinst.iso.torrent" ] });
+
+=head3 download tracker
+
+$res = $fbx->get_download_task( "$id/trackers");
+
+=head3 download peers
+
+$res = $fbx->get_download_task( "$id/peers");
+
+=head3 downloads task del with file erase
+
+$fbx->del_download_task( "$id/erase" );
+
 =head3 download feed
 
-$fbx->downloads_feeds( 1 );
+$res = $fbx->downloads_feeds;
 
-=head3 del feed
+=head3 add feed
 
-$fbx->del_feed( 1 );
+$res = $fbx->add_feed( "http://www.esa.int/rssfeed/Our_Activities/Space_News" );
 
 =head3 update feed
 
-$fbx->upd_feed(1, {auto_download=> \1});
+$fbx->upd_feed( $id , {auto_download=> \1} );
+
+=head3 download feed
+
+$res = $fbx->downloads_feeds("$id/items");
 
 =head3 refresh feed
 
-$fbx->refresh_feed("1/fetch");
+$fbx->refresh_feed( "$id/fetch" );
 
 =head3 refresh all feeds
 
@@ -906,51 +1038,43 @@ $fbx->refresh_feeds;
 
 =head3 download feed items
 
-$fbx->downloads_feeds("1/items");
+$fbx->downloads_feeds("$id/items");
 
 =head3 update a feed item
 
-$fbx->upd_feed("1/items/6");
+$fbx->upd_feed("$id/items/$id_file");
 
 =head3 download a feed item
 
-$fbx->download_feed_item("1/items/6/download");
+$fbx->download_feed_item("$id/items/$id_file/download");
 
 =head3 mark all items as read
 
-$fbx->mark_all_read( "1/items/mark_all_as_read" );
+$fbx->mark_all_read( "$id/items/mark_all_as_read" );
 
-=head3 add feed
+=head3 del feed
 
-$res = $fbx->add_feed("http://www.nzb-rss.com/rss/Debian-unstable.rss");
-
-=head3 update downloads config
-
-$res = $fbx->upd_downloads_config({max_downloading_tasks => 6, download_dir=>"/Disque dur/Téléchargements/"});
-
-=head3 update throttling
-
-$res = $fbx->upd_downloads_throttle( "schedule" );
+$fbx->del_feed( $id );
 
 =head3 download file to disk
 
 $res = $fbx->download_file( "Disque dur/Photos/cyril/DSCF4322.JPG" );
 
+=head3 download file to disk
+
+$res = $fbx->download_file( "Disque dur/Photos/cyril/DSCF4321.JPG" );
+
 =head3 get upload id
 
 $res = $fbx->upload_auth( {upload_name => "DSCF4322.JPG", dirname => "/Disque dur/"} );
 
 =head3 upload file by upload id
 
-$res = $fbx->upload_file( {id=> $res->{result}{id}, filename=>"DSCF4322.JPG"});
+$res = $fbx->upload_file( {id=> $res->{id}, filename=>"DSCF4322.JPG"});
 
 =head3 upload file directly
 
-$res = $fbx->upload_file( {filename => "DSCF4322.JPG", dirname => "/Disque dur/"} );
-
-=head3 downloads config
-
-$fbx->downloads_config;
+$res = $fbx->upload_file( {filename => "DSCF4321.JPG", dirname => "/Disque dur/"} );
 
 =head2 freeplugs
 
@@ -1006,15 +1130,31 @@ $fbx->ftp_config;
 
 =head3 lan config
 
-$fbx->lan_config;
+ $res = $fbx->lan_config;
 
 =head3 lan browser interfaces
 
-$res = $fbx->lan_browser_interfaces;
+ $res = $fbx->lan_browser_interfaces;
 
 =head3 lan browser interfaces pub
 
-$fbx->list_hosts($res->{result}->[0]->{name} );
+ $res = $fbx->list_hosts( $net );
+
+=head3 get host information
+
+ $res = $fbx->list_hosts("$net/$id");
+
+=head3 update host information
+
+ $res = $fbx->upd_host("$net/$id", { id => $id , host_type => "networking_device" });
+
+=head3 update lan config
+
+ $res = $fbx->upd_lan_config( {mode=>"router"} );
+
+=head3 send wol
+
+ $res = $fbx->wol_host( $net, {mac => "B8:27:EB:73:8C:4E"} );
 
 =head2 lcd
 
@@ -1024,7 +1164,7 @@ $res = $fbx->lcd;
 
 =head3 lcd brightness back
 
-$fbx->set_lcd({ brightness => $res->{result}{brightness} });
+$fbx->set_lcd({ brightness => $res->{brightness} });
 
 =head2 nat
 
@@ -1076,7 +1216,7 @@ $fbx->airmedia_receivers;
 
 =head3 netshare samba
 
-$fbx->netshare_samba;
+ $res = $fbx->netshare_samba;
 
 =head3 netshare afp
 
@@ -1096,7 +1236,19 @@ $fbx->storage_partition;
 
 =head3 switch status
 
-$fbx->switch_sts;
+ $res = $fbx->switch_sts;
+
+=head3 switch port config
+
+ $res = $fbx->switch_port(1);
+
+=head3 switch port stats
+
+ $res = $fbx->switch_port("1/stats/");
+
+=head3 set switch port config
+
+ $res = $fbx->set_switch_port(1 , {duplex=>"auto"} );
 
 =head2 system
 
@@ -1126,7 +1278,7 @@ $res=$fbx->upnpav;
 
 =head3 set upnpav
 
-$fbx->set_upnpav($res->{result}{enabled});
+$fbx->set_upnpav($res->{enabled});
 
 =head2 vpn
 
